@import 'libs/vars';
@import 'libs/functions';
@import 'libs/mixins';
@import 'libs/vendor';
@import 'libs/breakpoints';

/*
	Indivisible by Pixelarity
	pixelarity.com | hello@pixelarity.com
	License: pixelarity.com/license
*/

/* Panel */

	.panel {
		margin: 0 0 (_size(element-margin) * 1.5) 0;

		body.is-preload-0 & {
			opacity: 1;

			> .image {
				@include vendor('transform', 'none !important');
			}

			> .content {
				@include vendor('transform', 'none !important');
			}
		}
	}

/* Footer */

	#footer {
		margin-top: 0;

		body.is-preload-0 & {
			opacity: 1;
		}
	}