///
/// Indivisible by Pixelarity
/// pixelarity.com | hello@pixelarity.com
/// License: pixelarity.com/license
///

/* Icons */

	ul.icons {
		cursor: default;
		list-style: none;
		padding-left: 0;

		li {
			display: inline-block;
			padding-left: 0;

			.icon {
				display: inline-block;
				width: 2.5em;
				height: 2.5em;
				line-height: 2.5em;
				text-align: center;

				&:before {
					font-size: 1.25rem;
				}
			}
		}
	}